@@ -18,6 +18,7 @@ CLI_CONFIG = {
     "pyenv": {},
     "no_clean": {"action": "store_true",},
     "locale_utf8": {"options": ["--locale-utf8"], "action": "store_true",},
+    "release": {},
     "pkg_builder": {},
     "pkg_tgt": {},
     "srcdir": {},
@@ -89,6 +90,10 @@ CONFIG = {
                 dest: lib64/
                 """,
     },
+    "release": {
+        "default": {},
+        "help": "Release string i.e. '1.el7'. this is the fpm --iteration option.",
+    },
     "pkg": {"default": {}, "help": "Options for building packages"},
     "pkg_builder": {
         "default": PKG_BUILDER,
