@@ -25,7 +25,13 @@ def build(hub, bname):
         opts["onedir"],
     )
     cmd = _get_cmd(
-        opts["name"], root, opts["pkg"], opts["pkg_tgt"], opts["version"], config
+        opts["name"],
+        root,
+        opts["release"],
+        opts["pkg"],
+        opts["pkg_tgt"],
+        opts["version"],
+        config,
     )
     _run_fpm(cmd)
     # shutil.rmtree(root)
@@ -60,7 +66,7 @@ def _get_fpm_tgt(pkg_tgt):
         return "pacman"
 
 
-def _get_cmd(name, root, pkg, pkg_tgt, version, config):
+def _get_cmd(name, root, release, pkg, pkg_tgt, version, config):
     """
     Return the command line args list to shell out to fpm with
     """
@@ -73,6 +79,9 @@ def _get_cmd(name, root, pkg, pkg_tgt, version, config):
     if fpm_tgt == "rpm":
         cmd.append("--rpm-digest")
         cmd.append("sha512")
+    if release:
+        cmd.append("--iteration")
+        cmd.append(f"{release}")
     cmd.append("--version")
     cmd.append(version)
     cmd.append("-C")
