@@ -4,6 +4,7 @@ Create and manage the venvs used for build environments
 # Import python libs
 import venv
 import os
+import sys
 import shutil
 import subprocess
 import tarfile
@@ -77,9 +78,23 @@ def create(hub, bname):
         subprocess.run(f"{pip_cmd} install -U pip", shell=True)
         # I am hardcoding this in for now, it should be removed when Python 3.8 has been out longer
         subprocess.run(f"{pip_cmd} install distro", shell=True)
-        subprocess.run(f'{pip_cmd} install -r {opts["req"]}', shell=True)
+        reqcmd = subprocess.run(
+            f'{pip_cmd} install -r {opts["req"]}', shell=True
+        ).returncode
+        projcmd = 0
         if os.path.isfile(os.path.join(opts["dir"], "setup.py")):
-            subprocess.run(f'{pip_cmd} install {opts["dir"]}', shell=True)
+            projcmd = subprocess.run(
+                f'{pip_cmd} install {opts["dir"]}', shell=True
+            ).returncode
+        exit = False
+        if reqcmd != 0:
+            print("Failed to install requirements, please check pip output for details")
+            exit = True
+        if projcmd != 0:
+            print("Failed to setup project, please check pip output for details")
+            exit = True
+        if exit:
+            sys.exit(1)
     # Install old pycparser to fix: https://github.com/eliben/pycparser/issues/291 on Windows
     if opts["is_win"]:
         subprocess.run(f"{pip_cmd} install pycparser==2.14", shell=True)
